==> citron-0.6.0.crate: citron-0.6.0/src/fmt/uptime.rs <==
use std::fmt;

pub struct UptimeFormatter {
    days: u32,
    hours: u32,
    minutes: u32,
}

impl From<usize> for UptimeFormatter {
    fn from(seconds: usize) -> UptimeFormatter {
        let seconds = seconds as f32;
        let d = (seconds / 60.0 / 60.0 / 24.0).floor();
        let h = (seconds / 60.0 / 60.0 % 24.0).floor();
        let m = (seconds / 60.0 % 60.0).floor();

        UptimeFormatter {
            days: d as u32,
            hours: h as u32,
            minutes: m as u32,
        }
    }
}

impl fmt::Display for UptimeFormatter {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        let mut compiled: Vec<String> = vec![];

        match self.days {
            0 => (),
            1 => compiled.push("1 day".to_string()),
            d => compiled.push(format!("{} days", d)),
        }

        match self.hours {
            0 => (),
            1 => compiled.push("1 hour".to_string()),
            h => compiled.push(format!("{} hours", h)),
        }

        match self.minutes {
            0 => (),
            1 => compiled.push("1 minute".to_string()),
            m => compiled.push(format!("{} minutes", m)),
        }

        write!(f, "{}", compiled.join(", "))
    }
}

#[cfg(test)]
mod tests {
    use super::*;

    #[test]
    fn from_usize_to_uptime() {
        let fmt = UptimeFormatter::from(7500);
        assert_eq!(fmt.days, 0);
        assert_eq!(fmt.hours, 2);
        assert_eq!(fmt.minutes, 5);
    }

    #[test]
    fn display_uptime() {
        let fmt = UptimeFormatter::from(7260);
        assert_eq!(fmt.to_string(), "2 hours, 1 minute".to_owned());
    }
}

==> citron-0.11.0.crate: citron-0.11.0/src/fmt/uptime.rs <==
use super::Iconize;
use crate::Icon;
use std::fmt;

pub struct UptimeFormatter {
    days: u32,
    hours: u32,
    minutes: u32,
}

impl From<usize> for UptimeFormatter {
    fn from(seconds: usize) -> UptimeFormatter {
        let seconds = seconds as f32;
        let d = (seconds / 60.0 / 60.0 / 24.0).floor();
        let h = (seconds / 60.0 / 60.0 % 24.0).floor();
        let m = (seconds / 60.0 % 60.0).floor();

        UptimeFormatter {
            days: d as u32,
            hours: h as u32,
            minutes: m as u32,
        }
    }
}

impl Iconize for UptimeFormatter {
    fn set_icon(&self, icon: &mut Icon) {
        icon.find_icon("computer-symbolic")
    }
}

impl fmt::Display for UptimeFormatter {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        let mut compiled: Vec<String> = vec![];

        match self.days {
            0 => (),
            1 => compiled.push("1 day".to_string()),
            d => compiled.push(format!("{} days", d)),
        }

        match self.hours {
            0 => (),
            1 => compiled.push("1 hour".to_string()),
            h => compiled.push(format!("{} hours", h)),
        }

        match self.minutes {
            0 => (),
            1 => compiled.push("1 minute".to_string()),
            m => compiled.push(format!("{} minutes", m)),
        }

        write!(f, "{}", compiled.join(", "))
    }
}

#[cfg(test)]
mod tests {
    use super::*;

    #[test]
    fn from_usize_to_uptime() {
        let fmt = UptimeFormatter::from(7500);
        assert_eq!(fmt.days, 0);
        assert_eq!(fmt.hours, 2);
        assert_eq!(fmt.minutes, 5);
    }

    #[test]
    fn display_uptime() {
        let fmt = UptimeFormatter::from(7260);
        assert_eq!(fmt.to_string(), "2 hours, 1 minute".to_owned());
    }
}
